<?php

namespace IpQualityScore;

class Integration{

    private $secret;
    private $landingPage;

    public function __construct($secret,$landingPage){
       $this->secret = $secret;
       $this->landingPage = $landingPage;
    }

    public function getOverviewGraphs($output='html'){
        $url = 'https://www.ipqualityscore.com/webhooks/' . $this->landingPage . '/' . $output . '/overview';
        $fields = array(
            'secret' => $this->secret,
            'key' => urlencode($_SERVER['HTTP_HOST'])
        );
        $curl = curl_init();
        curl_setopt($curl, CURLOPT_URL, $url);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_FOLLOWLOCATION, true);
        curl_setopt($curl, CURLOPT_POST, 1);
        curl_setopt($curl, CURLOPT_POSTFIELDS, http_build_query($fields));
        $result = curl_exec($curl);
        $responseCode = curl_getinfo($curl, CURLINFO_HTTP_CODE);
        curl_close($curl);
        // TODO refactor, it always returns code 200
        if( $result == '<div class="error">Unable to authenticate with IPQualityScore or invalid API request. Please check your parameters.</div>1' ){
            return false;
        }
	
        return $result;
	
    }

    public function getProxyGraphs($output='html'){
        $url = 'https://www.ipqualityscore.com/webhooks/' . $this->landingPage . '/' . $output . '/proxy_statistics';
        $fields = array(
            'secret' => $this->secret,
            'key' => $_SERVER['HTTP_HOST']
        );
        $curl = curl_init();
        curl_setopt($curl, CURLOPT_URL, $url);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_FOLLOWLOCATION, true);
        curl_setopt($curl, CURLOPT_POST, 1);
        curl_setopt($curl, CURLOPT_POSTFIELDS, http_build_query($fields));
        $result = curl_exec($curl);
        $responseCode = curl_getinfo($curl, CURLINFO_HTTP_CODE);
        curl_close($curl);
        return $result;
    }

    public function getEmailGraphs($output='html'){
        $url = 'https://www.ipqualityscore.com/webhooks/' . $this->landingPage . '/' . $output . '/email_statistics';
        $fields = array(
            'secret' => $this->secret,
            'key' => $_SERVER['HTTP_HOST']
        );
        $curl = curl_init();
        curl_setopt($curl, CURLOPT_URL, $url);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_FOLLOWLOCATION, true);
        curl_setopt($curl, CURLOPT_POST, 1);
        curl_setopt($curl, CURLOPT_POSTFIELDS, http_build_query($fields));
        $result = curl_exec($curl);
        $responseCode = curl_getinfo($curl, CURLINFO_HTTP_CODE);
        curl_close($curl);
        return $result;
    }
 
    public function getDeviceGraphs($output='html'){
        $url = 'https://www.ipqualityscore.com/webhooks/' . $this->landingPage . '/' . $output . '/device_statistics';
        $fields = array(
            'secret' => $this->secret,
            'key' => $_SERVER['HTTP_HOST']
        );
        $curl = curl_init();
        curl_setopt($curl, CURLOPT_URL, $url);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_FOLLOWLOCATION, true);
        curl_setopt($curl, CURLOPT_POST, 1);
        curl_setopt($curl, CURLOPT_POSTFIELDS, http_build_query($fields));
        $result = curl_exec($curl);
        $responseCode = curl_getinfo($curl, CURLINFO_HTTP_CODE);
        curl_close($curl);
        return $result;
    }


    /*
    *   Check ip score
    *
    *   @param string $strictness
    *   @param boolean $allowPublicAccessPoints
    *   @param boolean $lighterPenalties
    *   @param boolean $force
    *   @param array $user
    *   @param string $email
    *   @return string
    */


    public function validateProxy($strictness=1,$allowPublicAccessPoints=true,$lighterPenalties = false,$force = false, array $user = []){
        $url = 'https://www.ipqualityscore.com/webhooks/' . $this->landingPage . '/json/proxy_check';
        $ip = isset($_SERVER['REMOTE_ADDR']) ? $_SERVER['REMOTE_ADDR'] : $_SERVER['HTTP_CLIENT_IP'];
        $hostname = gethostbyaddr($ip);
        $userAgent = $_SERVER['HTTP_USER_AGENT'];
        $userLanguage = $_SERVER['HTTP_ACCEPT_LANGUAGE'];

        // Return cached result

	$resource = \Mage::getSingleton('core/resource');
	$readConnection = $resource->getConnection('core_read');
	
	$query = $sql = "SELECT * FROM ipqualityscore_proxy WHERE host IN ('{$hostname}','{$ip}')";
	$data = $readConnection->fetchAll($query);
	if($data && !$force ){
	    $data[0] = (object) $data[0];
            $data[0]->cached = 1;
            return $data[0];
        }

        if($force){
             $resource = \Mage::getSingleton('core/resource');
             $writeConnection = $resource->getConnection('core_write');

             $sql ="DELETE FROM ipqualityscore_proxy WHERE host IN ('{$hostname}','{$ip}')";
             $writeConnection->query($sql);
        }

        $parameters = array(
            'secret' => $this->secret,
            'key' => $_SERVER['HTTP_HOST'],
            'ip' => $ip,
            'user_agent' => $userAgent,
            'user_language' => $userLanguage,
            'strictness' => $strictness,
            'allow_public_access_points' => $allowPublicAccessPoints,
            'lighter_penalties' => $lighterPenalties
        );
        if( $user ){
            $parameters['billing_first_name'] = $user['billing_firstname'];
            $parameters['billing_last_name'] = $user['billing_lastname'];
            $parameters['billing_company'] = $user['billing_company'];
            $parameters['billing_country'] = $user['billing_country'];
            $parameters['billing_address_1'] = $user['billing_address'];
            $parameters['billing_city'] = $user['billing_city'];
            $parameters['billing_state'] = $user['billing_state'];
            $parameters['billing_zipcode'] = $user['billing_postcalcode'];
            $parameters['billing_phone'] = $user['billing_phone'];
            $parameters['billing_email'] = $user['billing_email'];
            $parameters['shipping_first_name'] = $user['shipping_firstname'];
            $parameters['shipping_last_name'] = $user['shipping_lastname'];
            $parameters['shipping_company'] = $user['shipping_company'];
            $parameters['shipping_country'] = $user['shipping_country'];
            $parameters['shippping_address_1'] = $user['shipping_address'];
            $parameters['shipping_city'] = $user['shipping_city'];
            $parameters['shipping_state'] = $user['shipping_state'];
            $parameters['shipping_zipcode'] = $user['shipping_postcalcode'];
            $parameters['shipping_phone'] = $user['shipping_phone'];
            $parameters['shipping_email'] = $user['shipping_email'];
        }
        //var_dump($parameters);
        $curl = curl_init();
        curl_setopt($curl, CURLOPT_URL, $url);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_FOLLOWLOCATION, true);
        curl_setopt($curl, CURLOPT_POST, 1);
        curl_setopt($curl, CURLOPT_POSTFIELDS, http_build_query($parameters));
        $json = json_decode(curl_exec($curl));
        $response_code = curl_getinfo($curl, CURLINFO_HTTP_CODE);
        curl_close($curl);
        $json->cached = 0;
        return $json;
    }


    /*
    *  Check email validity
    *
    *   @param string $email
    *   @return string
    */

    public function validateEmail($email){
        $url = 'https://www.ipqualityscore.com/webhooks/' . $this->landingPage . '/json/email_check';
        $resource = \Mage::getSingleton('core/resource');
        $readConnection = $resource->getConnection('core_read');
        $sql = "SELECT * FROM ipqualityscore_email WHERE email = '{$email}'";
        $data = $readConnection->fetchAll($sql);
        if($data){
            $data[0] = (object) $data[0];
            $data[0]->cached = 1;
            return $data[0];
        }

        $parameters = array(
           'secret' => $this->secret,
            'key' => $_SERVER['HTTP_HOST'],
            'email' => $email,
            'timeout' => 20,
            'fast' => false
        );

        $curl = curl_init();
        curl_setopt($curl, CURLOPT_URL, $url);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_FOLLOWLOCATION, true);
        curl_setopt($curl, CURLOPT_POST, 1);
        curl_setopt($curl, CURLOPT_POSTFIELDS, http_build_query($parameters));
        $response_code = curl_getinfo($curl, CURLINFO_HTTP_CODE);
        $json = json_decode( curl_exec($curl) );
        curl_close($curl);
        $json->cached = 0;
        return $json;
     }


    /*
    *  Create device tracker url
    *
    *   @return object
    */

    public function createDeviceTrackerUrl(){
        $url = 'https://www.ipqualityscore.com/webhooks/' . $this->landingPage . '/json/generate_device_tracker';
        $fields = array(
        	'secret' => $this->secret,
         	'key' => $_SERVER['HTTP_HOST'],
         	'domain' => $_SERVER['HTTP_HOST']
        );
        $curl = curl_init();
        curl_setopt($curl, CURLOPT_URL, $url);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_FOLLOWLOCATION, true);
        curl_setopt($curl, CURLOPT_POST, 1);
        curl_setopt($curl, CURLOPT_POSTFIELDS, http_build_query($fields));
        $result = json_decode( curl_exec($curl) );

        $response_code = curl_getinfo($curl, CURLINFO_HTTP_CODE);
        curl_close($curl);
        if( $result->success ){
            return '<script src="'.$result->script_url.'"></script><noscript><img src="'.$result->pixel_url.'" /></noscript>';;
        }
        return '';
    }


    /*
    *  Get device tracker
    *
    *   @return object
    */

    public function getDeviceTracker(){
        $url = 'https://www.ipqualityscore.com/webhooks/' . $this->landingPage . '/json/generate_device_tracker';
        $fields = array(
                'secret' => $this->secret,
                'key' => $_SERVER['HTTP_HOST'],
        );
        $curl = curl_init();
        curl_setopt($curl, CURLOPT_URL, $url);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_FOLLOWLOCATION, true);
        curl_setopt($curl, CURLOPT_POST, 1);
        curl_setopt($curl, CURLOPT_POSTFIELDS, http_build_query($fields));
        $result = json_decode( curl_exec($curl) );

        $response_code = curl_getinfo($curl, CURLINFO_HTTP_CODE);
        curl_close($curl);
        return $result;
    }



    /*
    * Report an order
    *
    * @return object
     */

   public function report($requestId){
        $url = 'https://www.ipqualityscore.com/webhooks/' . $this->landingPage . '/json/report_order';
        $parameters = array(
            'secret' => $this->secret,
            'key' => $_SERVER['HTTP_HOST'],
            'request' => $requestId
        );
        $curl = curl_init();
        curl_setopt($curl, CURLOPT_URL, $url);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_FOLLOWLOCATION, true);
        curl_setopt($curl, CURLOPT_POST, 1);
        curl_setopt($curl, CURLOPT_POSTFIELDS, http_build_query($parameters));
        $json = json_decode(curl_exec($curl));
        $response_code = curl_getinfo($curl, CURLINFO_HTTP_CODE);
        curl_close($curl);
        return $json;
    }

    public function getLoginUrl(){
        $url = 'https://ipqualityscore.com/webhooks/' .  $this->landingPage.'/json/token';
        $parameters = array(
            'secret' => $this->secret,
            'key' => $_SERVER['HTTP_HOST']
        );
        $curl = curl_init();
        curl_setopt($curl, CURLOPT_URL, $url);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_FOLLOWLOCATION, true);
        curl_setopt($curl, CURLOPT_POST, 1);
        curl_setopt($curl, CURLOPT_POSTFIELDS, http_build_query($parameters));
        $json = json_decode(curl_exec($curl));
        $response_code = curl_getinfo($curl, CURLINFO_HTTP_CODE);
        curl_close($curl);
var_dump($url,$parameters,$json);die();
        return $json;
    }


	
}


